Laptop stands at Juno Records

Skip Navigation

Secure shopping

MP3, WAV, FLAC

Juno Download offers over 3 million dance tracks in MP3, WAV & FLAC formats, featuring genre pages, advanced audioplayer, super-fast download speeds.

Visit Juno Download

Secure shopping

Studio equipment

Our full range of studio equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices.

Visit Juno Studio

Secure shopping

DJ equipment

Our full range of DJ equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices. Visit Juno DJ

Online magazine

Features the latest dance music news, interviews, music and tech reviews, podcasts & more...

Visit Juno Plus

In:
Tweet

- Play All
  - Juno Player
  - M3U
  - XSPF

View:
Options
Options
Display

View: |
Items per page: |
Show tracks: |
Hide played by

Stock

Show out of stock titles

Misc

Save sort order

- Sort: Artist
  Bestseller:
  - High to low
  Artist:
  - ✓ A to Z
  - Z to A
  Title:
  - A to Z
  - Z to A
  Brand:
  - A to Z
  - Z to A
  Date:
  - Old to new
  - New to old
  Price:
  - Low to high
  - High to low

Items 1 to 26 of 26 on page 1 of 1
Add to cart
2 in stock £21.71
Accu Case Uni LTS Laptop Stand (laptop stand)
American Audio
Cat: 449717 Rel: 12 Mar 12
Laptop stand with tray and clamps
Notes: The Accu Case Uni LTS is a universal laptop stand for DJs, musicians, or lighting designers.
For use with almost any laptop, this stand can be assembled very easily and fits into nearly every gig bag. It includes a storage shelf that users can conveniently put their sound cards, hard drives or DMX lighting interfaces onto. The Uni LTS includes 2 x mounting options; one, which allows for the stand to sit directly onto a tabletop, and the other, allows for the stand to be securely attached to a gear case.
… Read more
Add to cart
2 in stock £104.16
Crane Elite Laptop Stand (black/silver) (laptop stand)
Crane
Cat: 561576 Rel: 02 Feb 15
Versatile laptop and DJ equipment stand with extremely lightweight design
Notes: The Crane Stand Elite is a Premium, Ultra Lightweight, Multi-Position, Fold Flat Laptop & Tablet Stand for DJs, Musicians, Producers and ANYONE in need of the highest quality laptop or tablet stand on Planet Earth.
The Crane Stand Elite is light-weight, durable and portable. Ideal for laptops, tablets, projectors, controllers, or any other comperable size/weight comparable electronic device.
The robust design of the Crane Elite Electronics Stand gives you the ultimate in space-saving flexibility, superior ergonomics, stability, and the best quality possible.
… Read more
Add to cart
2 in stock £83.33
Crane Pro Laptop Stand (black) (laptop stand)
Crane
Cat: 412635 Rel: 16 May 11
Portable & adjustable DJ laptop stand with carry bag
Notes: The Crane stand is the highest quality adjustable laptop stand on the market. Adjustable and portable, the patented ergonomic 3-leg design allows for an infinite number of positions making the Crane stand the most versatile and stable laptop stand.
The Crane stand was designed with the highest quality standards in mind. Using the highest quality materials, the Cranes laptop stand is hand-welded by expert craftsmen. They use local suppliers and sustainable business practices to create a product that will stand the test of time.
The Crane stand provides a robust way to elevate your laptop above any flat and stable surfaces to a variety of heights and angles. It can accommodate the smallest and largest laptop or other weight/size comparable component. Its unique 3-leg design allows you to slide the stand underneath the turntable, mixer or any other equipment you might use.
… Read more
Add to cart
1 in stock £20.42
Kam LS02 Laptop Stand (laptop stand)
Kam
Cat: 399248 Rel: 26 Jul 10
Notes: The Kam LS02 laptop stand has an ergonomic design for easy laptop access, complete with clamps for secure positioning, adjustable height & width and 3 different configurations available. It can be used for laptops or FX & lighting controllers and extensions are included for most laptop sizes. It's design also exsures good airflow around the laptop to prevent overheating.
… Read more
Add to cart
1 in stock £49.17
Magma Control Stand For DDJ S1/DDJ T1/NS6/S4/S2/MC6000/VMS4/VCI300 Mixer + Laptop / iPad (red) (DJ equipment stand)
Magma
Cat: 472241 Rel: 29 Oct 12
DJ equipment stand, fits 12" club mixer/DJ controller + laptop (13"-19")
Notes: This sturdy equipment stand is perfect for studio, club installations, as well as home use and can be placed over your existing DJ setup. When DJs are faced with the extreme lack of space in the DJ-booth and where to put my controller problem, this stand is a helpful space-saving solution for clubs as it fits perfectly over a 12" club mixer like a Pioneer DJM-800.
It also features non-slip rubber surface and feet to insure maximum stability during your performance and its overall elevated height provide best protection against spilled drinks, dirt, and more. The slightly angled controller and laptop platforms are both individually adjustable in height and width to find the right position for any controller setup.
Sturdy equipment stand to accommodate a DJ-controller and laptop at the same time.
… Read more
Add to cart
1 in stock £48.75
Magma Control Stand For DDJ S1/DDJ T1/NS6/S4/S2/MC6000/VMS4/VCI300 Mixer + Laptop/iPad (black) (controller stand)
Magma
Cat: 451989 Rel: 09 Apr 12
Equipment stand fits DDJ/NS-6/S4/S2/MC-6000/VMS-4/VCI-300/laptop/iPad
Notes: This sturdy equipment stand is perfect for studio, club installations, as well as home use and can be placed over your existing DJ setup. When DJs are faced with the extreme lack of space in the DJ-booth and where to put my controller problem, this stand is a helpful space-saving solution for clubs as it fits perfectly over a 12" club mixer like a Pioneer DJM-800. It also features non-slip rubber surface and feet to insure maximum stability during your performance and its overall elevated height provide best protection against spilled drinks, dirt, and more. The slightly angled controller and laptop platforms are both individually adjustable in height and width to find the right position for any controller setup.
… Read more
Add to cart
1 in stock £44.96
Magma Control Stand For DDJ S1/DDJ T1/NS6/S4/S2/MC6000/VMS4/VCI300 Mixer + Laptop/iPad (black) (B-STOCK) (controller stand)
Magma
Cat: 594819 Rel: 09 Apr 12
B-STOCK: Box opened, product in perfect working order
Notes: ***B-STOCK: Box opened, product in perfect working order***
This sturdy equipment stand is perfect for studio, club installations, as well as home use and can be placed over your existing DJ setup. When DJs are faced with the extreme lack of space in the DJ-booth and where to put my controller problem, this stand is a helpful space-saving solution for clubs as it fits perfectly over a 12" club mixer like a Pioneer DJM-800. It also features non-slip rubber surface and feet to insure maximum stability during your performance and its overall elevated height provide best protection against spilled drinks, dirt, and more. The slightly angled controller and laptop platforms are both individually adjustable in height and width to find the right position for any controller setup.
… Read more
Add to cart
1 in stock £9.99
Magma Laptop Stand Traveler Tray (black) (laptop stand tray)
Magma
Cat: 512427 Rel: 11 Nov 13
Aluminium tray for Magma laptop stand
Notes: The Traveler Tray can be easily attached to the MAGMA Laptop-Stand Traveler and provides a useful storage place e.g for an interface, a hard drive or an iPad.
… Read more
Add to cart
1 in stock £9.99
Magma Laptop Stand Traveler Tray (silver) (laptop stand tray)
Magma
Cat: 512429 Rel: 11 Nov 13
Aluminium tray for Magma laptop stand
Notes: The Traveler Tray can be easily attached to the MAGMA Laptop-Stand Traveler and provides a useful storage place e.g for an interface, a hard drive or an iPad.
… Read more
Add to cart
2 in stock £47.49
Odyssey L Stand 360 Ultra Laptop & Tablet Folding Stand (black) (laptop/tablet stand)
Odyssey
Cat: 553196 Rel: 17 Aug 15
Laptop and tablet folding stand, nop assembly required - adjustable height settings
Notes: From the same innovators that brought you the original L STAND, the most popular DJ laptop stand series ever brought to market, now comes the exciting new L Stand 360 Ultra. With its 360 degree rotating arms and legs and adjustable body height, the L Stand 360 Ultra design makes it the most flexible laptop/tablet stand ever made.
It's the lightest in the industry with the quickest adjustable setup of multiple heights and angles. Perfect for today's jet-set mobile DJs. Ultra light...Ultra easy to use...Ultra quick...Ultra cool. Double Ultra all the way!
… Read more
Add to cart
1 in stock £35.00
Odyssey L Stand M Folding Laptop Stand (black) (laptop stand (black))
Odyssey
Cat: 350232 Rel: 13 Apr 09
Laptop stand for mobile DJs, fully adjustable with many possible applications
Notes: Odyssey's folding L STAND MOBILE is a light and portable stand to place your laptop, CD/Digital Media Player, compact DJ Controller, Midi Effects/Drum machines, or lighting controller. Odyssey's L STAND MOBILE comes complete with stand alone legs for a table top configuration and clamps so it can be fixed to the edge of a table or the wall of your case just the way you like.
… Read more
FORTHCOMING
e-mail me when released
coming soon £29.17
Reloop Laptop Stand Flex (laptop stand)
Reloop
Cat: 452433 Rel: 14 Sep 15
Adjustable and foldable laptop stand
Notes: Sometimes it is the little, simple things in a DJ's life that make the job easier.
Reloop's vertically adjustable, foldable Laptop Stand Flex is the right choice when there is not much space in the DJ booth or if you need a light, absolutely sturdy laptop stand for the road. When folded, Reloop's Laptop Stand Flex can be placed in every equipment bag thus becoming a safe, rugged companion for your club gigs. And thanks to the vertical adjustment it can be adapted to every setup.
… Read more
Add to cart
2 in stock £20.83
Reloop Laptop Stand V2 (laptop stand)
Reloop
Cat: 363994 Rel: 17 Aug 09
Notes: The Reloop Laptop Stand V.2 is the enhanced assistant for the installation of laptops or other hardware in a DJ setup. Thanks to the variable width notebooks of all sizes can be set up safely and space-savingly.
… Read more
Add to cart
1 in stock £20.83
Reloop Laptop Stand V2 (limited edition white) (laptop stand)
Reloop
Cat: 417977 Rel: 28 Feb 11
Notes: The Reloop Laptop Stand V.2 is the enhanced assistant for the installation of laptops or other hardware in a DJ setup. Thanks to the variable width notebooks of all sizes can be set up safely while saving space.
… Read more
Add to cart
5 in stock £25.00
Reloop Modular Stand For DJ Equipment/Laptops/Tablets (DJ equipment stand)
Reloop
Cat: 549834 Rel: 05 Jan 15
Sturdy stand for modular controllers, specifically designed to fit Reloop Neon controller
Notes: The Reloop Modular Stand was designed to exactly fit the performance pad controller Reloop Neon, guaranteeing solid foothold with ideal working height. Ideally, the Reloop Modular Stand is positioned near a turntable, allowing comfortable access to the sample, cue, loop and effect sections. Thanks to convenient snap-in knobs, the Reloop Modular Stand's setup is quick and easy.
The stand is also compatible with other modular controllers, effect devices or even the iPad and it can also be used in the studio, in order to position your desktop synthesizer or drum machine at an ideal working height.
… Read more
FORTHCOMING
e-mail me when released
coming soon £47.49
Samson LTS50 Laptop Stand (laptop stand)
Samson
Cat: 586841 Rel: 28 Sep 15
Adjustable laptop stand with tripod base & silicon surface to hold laptop securely
Notes: Samson's LTS50 Laptop Stand offers convenient, comfortable placement of your laptop computer in live and studio environments. The lightweight LTS50 offers a roadworthy, steel-constructed design with a sleek black finish, as well as a removable top and fold-up design for increased portability.
The top part of the stand features a silicon surface to hold your laptop securely in place with tilt control for optimal positioning in any application. Adjustable up to 4.5" in height with locking latches and a pin lock for increased support, you can count on the LTS50 to keep your laptop right at your fingertips and ready to perform.
… Read more
Add to cart
2 in stock £74.99
Stanton Uberstand Laptop Stand With Bag (black) (laptop stand)
Stanton
Cat: 397926 Rel: 05 Jul 10
Foldable laptop stand with shelf for accessories
Notes: The Uberstand laptop stand is an essential tool for the traveling laptop DJ and musician. Most DJ booths and performance venues were not designed to accommodate a laptop, which creates a hassle for the DJ in many spaces. The Uberstand alleviates this issue. Folded, the Uberstand is the perfect travel companion to your laptop. Unfolded, its striking industrial design comes to life and safely elevates your laptop above your work space while providing a specially crafted shelf for your external hard-drive.
… Read more
Add to cart
5 in stock £66.66
Stanton Uberstand Laptop Stand With Bag (silver) (laptop stand)
Stanton
Cat: 294902 Rel: 17 Dec 07
Foldable laptop stand with shelf for accesories
Notes: The Stanton Uberstand is a stable, rugged laptop stand for use by DJs & musicians, that folds flat into a 12'' zippered bag (included). Constructed from aluminium & stainless steel, its lightweight & small folded form make it easy to transport.The Stanton Uberstand is a stable, rugged laptop stand for use by DJs & musicians, that folds flat into a 12'' zippered bag (included). Constructed from aluminium & stainless steel, its lightweight & small folded form make it easy to transport.
… Read more
Add to cart
1 in stock £49.17
Stanton Uberstand Laptop Stand With Bag (silver) (B-STOCK) (laptop stand)
Stanton
Cat: 576609 Rel: 08 Jun 15
***B-STOCK: Box opened, product unused***
Notes: The Stanton Uberstand is a stable, rugged laptop stand for use by DJs & musicians, that folds flat into a 12'' zippered bag (included). Constructed from aluminium & stainless steel, its lightweight & small folded form make it easy to transport.The Stanton Uberstand is a stable, rugged laptop stand for use by DJs & musicians, that folds flat into a 12'' zippered bag (included). Constructed from aluminium & stainless steel, its lightweight & small folded form make it easy to transport.
… Read more
Add to cart
5 in stock £87.50
UDG Creator Adjustable Aluminium Laptop & Controller Stand (laptop stand)
UDG
Cat: 492398 Rel: 26 Aug 13
All purpose foldable laptop / controller stand
Notes: UDG is pleased to present its first laptop stand branded under its Creator series of DJ accessories. UDG's Laptop / controller stand aluminum is the DJ's computer elevation station. Every performer who uses a computer including DJ's, producers and other musicians can appreciate this high quality piece of equipment. It's the only laptop stand for DJ's that balances solid, secure construction, portable, foldaway, height and angle adjustable, 360 degrees rotatable, low weight design and excellent affordability. UDG's stand is fast to assemble.
Solid and easy-to-assemble laptop/controller stand for DJs/Producers
High quality aircraft grade anodized aluminum
Height adjustable
Angle adjustable
360-degree rotatable
Removable sub tray
Fit 's 13"-18" laptop, iPad or controller
Airflow constructed tray prevents equipment from overheating
Protective neoprene sleeve included
Folded
only 4.5 cm / 1.8 inch thick when folded
47 (H) x 34 (W) x 28 (D) cm
18.5 (H) x 13.4 (W) x 11 (D) inches
Weight
1.6 kg / 3.5 lbs
Stand fully extended
… Read more
Add to cart
1 in stock £40.83
Ultimate Support HYP50 HyperPad 5 In 1 Professional iPad Mini Stand (tablet stand)
Ultimate Support
Cat: 526993 Rel: 05 May 14
5-in-1 Professional iPad mini stand with included mic stand pole clamp, table clamp, and gooseneck extension
Notes: Ultimate Support's HyperPad mini is the industry's first 5-in-1 stand for the iPad mini! Whether you're using your iPad mini at home, at work, while singing at the coffee shop, out gigging with your guitar or keyboard, or laying down beats at the club, HyperPad mini has you covered.
Whether you're listening to music, watching a movie, checking email, or investigating today's weather, HyperPad mini is the iPad mini stand you've been waiting for. Fully capable of securely holding your iPad mini in both landscape and portrait view (and at varying angles), the HyperPad mini secures your iPad mini on all four sides. The handy kickback support leg rotates and angles so you're free to adjust it to any arrangement you need.
Keeping lyrics, set lists, charts, and other important information readily available to you while on stage is a musician's dream come true. In today's digital world you can finally retire all your gigging binders, folders, napkins, and notebooks. Keeping it within arms reach, the HyperPad mini includes a mic stand pole clamp that securely attaches to poles from .8" to 1.25". We've included an adjustable gooseneck attachment for further personalized positioning!
Sometimes, you simply want a secure way to position your iPad mini on a table. So, whether it's your studio desk, DJ coffin, or the kitchen table, the included desktop clamp and gooseneck arm mounts to any flat surface from .5" to 1.6" in thickness providing a flexible, secure mounting option for your iPad mini.
In addition to clamping the HyperPad mini to the pole of your mic stand, the HyperPad mini can be mounted to the top of a microphone stand (5/8" thread) with the included gooseneck arm! So, if you want to make great use of that extra mic stand you have laying around in the garage, or simply prefer vertical access to your iPad mini, the Ultimate Support HyperPad mini delivers!
… Read more
Add to cart
2 in stock £18.33
Ultimate Support LPT100 JamStands Single Tier Multi Purpose Laptop Stand (laptop stand)
Ultimate Support
Cat: 528668 Rel: 28 Jul 14
Single-tier, multi-purpose laptop/DJ stand with stand alone base & multi-use surface clamps
Notes: While the JS-LPT100 is the perfect laptop stand for musicians and DJs on the go, in the studio, or even in the office, it's also a great option when you need a portable, sturdy stand for elevating a lighting controller, small mixer, CD player, multi-track recorder, DJ equipment, and more.
With five adjustable height positions, the JS-LPT100 puts your laptop or small, digital and analog sound equipment at just the right height. It also features three fixed width positions to hold a variety of music gear, and offers an angled platform with rubber friction pads and front bumpers to ensure your laptop's safety.
You can use the JS-LPT100 free standing on a desk, clamped horizontally to the edge of a table or rack case, or even clamped vertically to the case of your DJ equipment. It ships with one set of 12" support legs for use on flat surfaces and a set of clamps for mounting horizontally or vertically.
… Read more
Add to cart
3 in stock £21.66
Ultimate Support LPT200 JamStands Double Tier Multi Purpose Laptop Stand (laptop stand)
Ultimate Support
Cat: 528671 Rel: 05 May 14
Double-tier, multi-purpose laptop/DJ stand with stand alone base
Notes: While the JS-LPT200 is the perfect laptop stand for musicians and DJs on the go, in the studio, or even in the office, it's also a great option when you need a portable, sturdy stand for elevating a lighting controller, small mixer, CD player, multi-track recorder, DJ equipment, and more.
With five adjustable height positions, the JS-LPT200 puts your laptop or small, digital and analog sound equipment at just the right height. It also features three fixed width positions to hold a variety of music gear, and offers an angled platform with rubber friction pads and front bumpers to ensure your laptop's safety.
The Accessory Platform is the perfect place to hold hard drives, USB hubs, MP3 players, CDs, and other laptop and music accessories. It's vented, so your accessories won't overheat, and is also height and width adjustable.
… Read more
Add to cart
1 in stock £53.33
Zomo LS10 Laptop Stand (black) (laptop stand)
Zomo
Cat: 396540 Rel: 05 Jul 10
laptop stand
Notes: The Zomo LS-10 is the logic evolution of the Zomo LS-1. The easy-to-mount laptop stand LS-10 can be due to the ingenious folding technique in just a few seconds completely assembled or dismantled, without fixing a single nut or bolt. This is especially appreciated during mobile use very much. So that the tool can stay future at home!
The storage space can be divided into two different positions / preferences lock, whereby the laptop is placed either horizontally or easily bent on the stand. Besides the height can be adjusted and adapted the position perfectly in few handles by opening four screw connections (without tool). This makes it even more flexible and faster. The Zomo LS-10 laptop stand can be fixed easily, like his predecessor on almost every flight cases, as a clip version on all desktops or set as an on-the-top version to the DJ booth, or slide under the mixer or turntable. In addition, the Zomo LS-10 is delivered in a high quality, practical Neophren bag, thus can store the Zomo LS-10 space before and after use and protect it from damage.
… Read more
Add to cart
2 in stock £13.60
Zomo LS1s Laptop Stand Tray Shelf (white) (laptop stand shelf)
Zomo
Cat: 396537 Rel: 12 Jul 10
Laptop stand shelf
Notes: The Zomo laptop stand LS-1 is a easy-to-build and solid laptop stand which can be set up and down within a few movements. This stand has been built especially for DJ purposes but can also be used for every other application like notebook holder etc. The height can be adjusted individually in 4 different steps, the width in 2 steps. Therefore the Zomo LS-1 works as a perfect bracket for all different laptop models.
With the 3 different possibilities of mounting, on-the-top version, clip version or simply mounting it on a flightcase, this little helper can be installed very easily. The Zomo LS-1s storage compartment is optionally available as an additional and offers a perfect space for all common amps of the Digital Systems Rane Serato Scratch, Traktor Scratch, Stanton Final Scratch etc.
… Read more
Add to cart
2 in stock £42.49
Zomo LS50 Laptop Stand (black) (laptop stand)
Zomo
Cat: 431829 Rel: 01 Aug 11
Notes: The Zomo LS-50 laptop stand is an useful and fortunate accessory for mobile DJs and musicians.
Most DJ-Desks are not offering much space to place own equipment, the LS-50 is the perfect solution to place a lot of equipment on minimal space. Laptops, controllers, mixer and CD-players can be placed easily and fast with the Zomo LS-50 laptop stand. All established laptops and other equipment can be used in combination with the LS-50.
The height and angle can be adjusted perfectly in just a few handles by opening four screw connections (without tool). This makes the Zomo LS-50 even more flexible and faster.
The Zomo LS-50 laptop stand can be fixed easily, like his predecessor on almost every flight cases, as a clip version on all desktops or set as an on-the-top version to the DJ booth, or slide under the mixer or turntable.
Sheer genius and totally cool. It's Zomo.
… Read more
Items 1 to 26 of 26 on page 1 of 1

Finance option |
Deposit |

Monthly payment |
Number of monthly payments |
Cash price |
Deposit to pay |
Loan amount |
Loan repayment |
Cost of loan |
Total amount payable |

Only available to UK residents over 18, subject to terms and conditions. More info here.

These rates of finance are based on this specific product and can be applied for once this item has been added to the cart. Adding other products to your cart may change the rate of finance or deposit required.

Checkout and apply for finance now
Close